﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using System.IO;

namespace Files
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent ();

            treeView1.ShowNodeToolTips = true;
            treeView1.Nodes.Clear ();

            DriveInfo [] drives = DriveInfo.GetDrives ();
            foreach (var disk in drives)
                display (treeView1.Nodes, disk.RootDirectory, 2);
        }

        private void display (TreeNodeCollection branch, 
                              DirectoryInfo dir, 
                              int level)
        {
            MyNode node = new MyNode ();
            node.Text = dir.Name;
            node.ToolTipText = dir.FullName;
            node.path = dir.FullName;
            branch.Add(node);

            if (level > 1)
                update (node, dir, level - 1);
        }

        private void update (MyNode target,
                             DirectoryInfo dir,
                             int level)
        {
            target.ready = true;
            try
            {
                DirectoryInfo[] subdirs = dir.GetDirectories();
                foreach (var d in subdirs)
                    display(target.Nodes, d, level);
            }
            catch (Exception ex)
            {
            }
        }

        private void treeView1_BeforeExpand(object sender, TreeViewCancelEventArgs e)
        {
            foreach (TreeNode n in e.Node.Nodes)
            {
                MyNode m = n as MyNode;
                if (m != null && !m.ready)
                    update (m, new DirectoryInfo(m.path), 1);
            }
        }

        private void treeView1_AfterSelect(object sender, TreeViewEventArgs e)
        {
            listView1.ShowItemToolTips = true;
            listView1.Items.Clear ();
            toolStripStatusLabel1.Text = "";

            MyNode node = e.Node as MyNode;
            if (node != null)
            {
                DirectoryInfo dir = new DirectoryInfo(node.path);
                try
                {
                    foreach (FileInfo f in dir.GetFiles())
                    {
                        ListViewItem item = new ListViewItem();
                        item.Text = f.Name;
                        item.ToolTipText = f.FullName;
                        item.Tag = f.FullName;
                        item.SubItems.Add(f.Length.ToString("### ### ##0"));
                        item.SubItems.Add(f.LastWriteTime.ToString("yyyy-MM-dd HH:mm:ss.fffff"));

                        listView1.Items.Add(item);
                    }
                }
                catch (Exception ex)
                {
                    String[] lines = ex.Message.Split ('\r');
                    toolStripStatusLabel1.Text = lines [0];
                }
            }

        }

        private void listView1_ItemSelectionChanged(object sender, ListViewItemSelectionChangedEventArgs e)
        {
            foreach (ListViewItem item in listView1.SelectedItems)
            {
                String fileName = item.Tag as String;
                if (fileName != null)
                {
                    FileInfo fi = new FileInfo (fileName);
                    switch (fi.Extension)
                    {
                        case ".jpg":
                        case ".jpeg":
                            pictureBox1.Image = new Bitmap(fileName);
                            tabControl1.SelectedTab = imagePage;
                            break;
                        case ".htm":
                        case ".html":
                            webBrowser1.Url = new Uri ("file:/" +fileName);
                            tabControl1.SelectedTab = htmlPage;
                            break;
                    }

                }
            }
        }
    }
}
